@@ -1,8 +1,8 @@
 package v1
 
 import (
-	"github.com/icinga/icingadb/pkg/contracts"
-	"github.com/icinga/icingadb/pkg/types"
+	"github.com/icinga/icinga-go-library/database"
+	"github.com/icinga/icinga-go-library/types"
 )
 
 type Downtime struct {
@@ -30,6 +30,6 @@ type Downtime struct {
 	ZoneId             types.Binary    `json:"zone_id"`
 }
 
-func NewDowntime() contracts.Entity {
+func NewDowntime() database.Entity {
 	return &Downtime{}
 }
