@@ -4,23 +4,22 @@ import (
 	"github.com/icinga/icinga-go-library/database"
 	"github.com/icinga/icinga-go-library/types"
 	"github.com/icinga/icingadb/pkg/contracts"
-	icingadbTypes "github.com/icinga/icingadb/pkg/icingadb/types"
 )
 
 type Notification struct {
 	EntityWithChecksum    `json:",inline"`
 	EnvironmentMeta       `json:",inline"`
 	NameCiMeta            `json:",inline"`
-	HostId                types.Binary                     `json:"host_id"`
-	ServiceId             types.Binary                     `json:"service_id"`
-	NotificationcommandId types.Binary                     `json:"notificationcommand_id"`
-	TimesBegin            types.Int                        `json:"times_begin"`
-	TimesEnd              types.Int                        `json:"times_end"`
-	NotificationInterval  uint32                           `json:"notification_interval"`
-	TimeperiodId          types.Binary                     `json:"timeperiod_id"`
-	States                icingadbTypes.NotificationStates `json:"states"`
-	Types                 icingadbTypes.NotificationTypes  `json:"types"`
-	ZoneId                types.Binary                     `json:"zone_id"`
+	HostId                types.Binary `json:"host_id"`
+	ServiceId             types.Binary `json:"service_id"`
+	NotificationcommandId types.Binary `json:"notificationcommand_id"`
+	TimesBegin            types.Int    `json:"times_begin"`
+	TimesEnd              types.Int    `json:"times_end"`
+	NotificationInterval  uint32       `json:"notification_interval"`
+	TimeperiodId          types.Binary `json:"timeperiod_id"`
+	States                uint8        `json:"states"`
+	Types                 uint16       `json:"types"`
+	ZoneId                types.Binary `json:"zone_id"`
 }
 
 type NotificationUser struct {
