@@ -188,6 +188,8 @@ CREATE TABLE host (
   check_interval int unsigned NOT NULL,
   check_retry_interval int unsigned NOT NULL,
 
+  total_children int unsigned DEFAULT NULL,
+
   active_checks_enabled enum('n', 'y') NOT NULL,
   passive_checks_enabled enum('n', 'y') NOT NULL,
   event_handler_enabled enum('n', 'y') NOT NULL,
@@ -307,12 +309,15 @@ CREATE TABLE host_state (
   is_flapping enum('n', 'y') NOT NULL,
   is_overdue enum('n', 'y') NOT NULL,
 
-  is_acknowledged enum('n', 'y', 'sticky') NOT NULL,
+  is_acknowledged enum('n', 'y') NOT NULL,
+  is_sticky_acknowledgement enum('n', 'y') NOT NULL,
   acknowledgement_comment_id binary(20) DEFAULT NULL COMMENT 'comment.id',
   last_comment_id binary(20) DEFAULT NULL COMMENT 'comment.id',
 
   in_downtime enum('n', 'y') NOT NULL,
 
+  affects_children enum('n', 'y') NOT NULL,
+
   execution_time int unsigned DEFAULT NULL,
   latency int unsigned DEFAULT NULL,
   check_timeout int unsigned DEFAULT NULL,
@@ -356,6 +361,8 @@ CREATE TABLE service (
   check_interval int unsigned NOT NULL,
   check_retry_interval int unsigned NOT NULL,
 
+  total_children int unsigned DEFAULT NULL,
+
   active_checks_enabled enum('n', 'y') NOT NULL,
   passive_checks_enabled enum('n', 'y') NOT NULL,
   event_handler_enabled enum('n', 'y') NOT NULL,
@@ -476,12 +483,15 @@ CREATE TABLE service_state (
   is_flapping enum('n', 'y') NOT NULL,
   is_overdue enum('n', 'y') NOT NULL,
 
-  is_acknowledged enum('n', 'y', 'sticky') NOT NULL,
+  is_acknowledged enum('n', 'y') NOT NULL,
+  is_sticky_acknowledgement enum('n', 'y') NOT NULL,
   acknowledgement_comment_id binary(20) DEFAULT NULL COMMENT 'comment.id',
   last_comment_id binary(20) DEFAULT NULL COMMENT 'comment.id',
 
   in_downtime enum('n', 'y') NOT NULL,
 
+  affects_children enum('n', 'y') NOT NULL,
+
   execution_time int unsigned DEFAULT NULL,
   latency int unsigned DEFAULT NULL,
   check_timeout int unsigned DEFAULT NULL,
@@ -539,6 +549,8 @@ CREATE TABLE icingadb_instance (
   icinga2_flap_detection_enabled enum('n', 'y') NOT NULL,
   icinga2_performance_data_enabled enum('n', 'y') NOT NULL,
 
+  icingadb_version varchar(255) NOT NULL,
+
   PRIMARY KEY (id)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin ROW_FORMAT=DYNAMIC;
 
@@ -1334,6 +1346,63 @@ CREATE TABLE sla_history_downtime (
   INDEX idx_sla_history_downtime_env_downtime_end (environment_id, downtime_end) COMMENT 'Filter for sla history retention'
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin ROW_FORMAT=DYNAMIC;
 
+CREATE TABLE redundancy_group (
+  id binary(20) NOT NULL COMMENT 'sha1(name + all(member parent_name + timeperiod.name + states + ignore_soft_states))',
+  environment_id binary(20) NOT NULL COMMENT 'environment.id',
+  display_name text NOT NULL,
+
+  CONSTRAINT pk_redundancy_group PRIMARY KEY (id)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin ROW_FORMAT=DYNAMIC;
+
+CREATE TABLE redundancy_group_state (
+  id binary(20) NOT NULL COMMENT 'redundancy_group.id',
+  environment_id binary(20) NOT NULL COMMENT 'environment.id',
+  redundancy_group_id binary(20) NOT NULL COMMENT 'redundancy_group.id',
+  failed enum('n', 'y') NOT NULL,
+  is_reachable enum('n', 'y') NOT NULL,
+  last_state_change BIGINT UNSIGNED NOT NULL,
+
+  CONSTRAINT pk_redundancy_group_state PRIMARY KEY (id),
+
+  UNIQUE INDEX idx_redundancy_group_state_redundancy_group_id (redundancy_group_id)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin ROW_FORMAT=DYNAMIC;
+
+CREATE TABLE dependency_node (
+  id binary(20) NOT NULL COMMENT 'host.id|service.id|redundancy_group.id',
+  environment_id binary(20) NOT NULL COMMENT 'environment.id',
+  host_id binary(20) DEFAULT NULL COMMENT 'host.id',
+  service_id binary(20) DEFAULT NULL COMMENT 'service.id',
+  redundancy_group_id binary(20) DEFAULT NULL COMMENT 'redundancy_group.id',
+
+  CONSTRAINT pk_dependency_node PRIMARY KEY (id),
+
+  UNIQUE INDEX idx_dependency_node_host_service_redundancygroup_id (host_id, service_id, redundancy_group_id),
+  CONSTRAINT ck_dependency_node_either_checkable_or_redundancy_group_id CHECK (
+    IF(redundancy_group_id IS NULL, host_id IS NOT NULL, host_id IS NULL AND service_id IS NULL) = 1
+  )
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin ROW_FORMAT=DYNAMIC;
+
+CREATE TABLE dependency_edge_state (
+  id binary(20) NOT NULL COMMENT 'sha1([dependency_edge.from_node_id|parent_name + timeperiod.name + states + ignore_soft_states] + dependency_edge.to_node_id)',
+  environment_id binary(20) NOT NULL COMMENT 'environment.id',
+  failed enum('n', 'y') NOT NULL,
+
+  CONSTRAINT pk_dependency_edge_state PRIMARY KEY (id)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin ROW_FORMAT=DYNAMIC;
+
+CREATE TABLE dependency_edge (
+  id binary(20) NOT NULL COMMENT 'sha1(from_node_id + to_node_id)',
+  environment_id binary(20) NOT NULL COMMENT 'environment.id',
+  from_node_id binary(20) NOT NULL COMMENT 'dependency_node.id',
+  to_node_id binary(20) NOT NULL COMMENT 'dependency_node.id',
+  dependency_edge_state_id binary(20) NOT NULL COMMENT 'dependency_edge_state.id',
+  display_name text NOT NULL,
+
+  CONSTRAINT pk_dependency_edge PRIMARY KEY (id),
+
+  UNIQUE INDEX idx_dependency_edge_from_node_to_node_id (from_node_id, to_node_id)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin ROW_FORMAT=DYNAMIC;
+
 CREATE TABLE icingadb_schema (
   id int unsigned NOT NULL AUTO_INCREMENT,
   version smallint unsigned NOT NULL,
@@ -1343,4 +1412,4 @@ CREATE TABLE icingadb_schema (
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin ROW_FORMAT=DYNAMIC;
 
 INSERT INTO icingadb_schema (version, timestamp)
-  VALUES (6, UNIX_TIMESTAMP() * 1000);
+  VALUES (7, UNIX_TIMESTAMP() * 1000);
